==> Bundle-CGI-Dependencies-0.01.tar.gz: Bundle-CGI-Dependencies-0.01/lib/Bundle/CGI/Dependencies.pm <==
package Bundle::CGI::Dependencies;

use strict;
use warnings;

our $VERSION = '0.01';



1;
__END__


=head1 NAME

Bundle::CGI::Dependencies - installs CGI prerequisites

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::CGI::Dependencies'

=head1 CONTENTS

CGI

File::Spec

Pod::Parser

Test::Harness

Test::Simple

Attribute::Handlers

Params::Validate

Getopt::Long

XSLoader

Data::Dumper

Module::Info

PadWalker

B::Utils

Text::Abbreviate

Text::Balanced 

Algorithm::Diff

Scalar::List::Utils

IO

IO::Stringy

Getopt::Long

DBI

Getopt::Long::Descriptive

Data::Dump::Streamer

DBD::mysql

Regexp::Common

DBD::mysql::SimpleMySQL 

Devel::Leak

YAML

YAML::Syck

YAML::Tiny

Storable

ExtUtils::Constant

Time::HiRes

IPC::Run3

Test::Script

AutoLoader

HTML::Template

MIME::Base64

Digest

Digest::MD5

HTML::Tagset

HTML::Tree

HTML::Element::Library

HTML::Element::Convert

XML::TreeBuilder

HTML::ElementTable

HTML::TableExtract

XML::Parser

Test

version

ExtUtils::CBuilder

Config::IniFiles

Jcode

Encode

Bundle::Compress::Zlib

URI

HTTP::Daemon

Continuity

DBIx::ContextualFetch

UNIVERSAL::moniker

Clone

Ima::DBI

Class::Trigger

Class::Data::Inheritable

Class::DBI

Class::Contract

Pragmatic

Class::ISA

Class::Class

Class::Generate

Class::MethodMaker

CGI::Ajax

Digest::SHA1

Crypt::CBC

Crypt::DES

Crypt::DES_EDE3

Crypt::IDEA

Crypt::CAST5

Crypt::Rijndael

Crypt::Rijndael_PP

Crypt::Blowfish

DBD::SQLite

Bundle::SQL

Test::Exception

HTTP::Rollup

Template::StringTree

Test::Assertions

Hash::Flatten

Log::Trace

Tie::ShareLite

IPC::Shareable

IPC::ShareLite

MIME::Types

Number::Compare

Text::Glob

Number::Compare

File::Find::Rule

File::Find::Rule::Type

File::Find::Rule::MMagic

File::Type

Cache::Cache

Crypt::UnixCrypt

Module::Load

Tree::DAG_Node

Sub::Uplevel

Array::Compare

UNIVERSAL::require

Test::Warn

Apache::Htgroup

Sub::Name

Class::MOP

Class::Accessor

HTML::Prototype

Module::Build

Template

IO::Zlib

File::Which

Digest::SHA::PurePerl

PAR::Dist

Archive::Zip

PAR 

Acme::Intraweb

Test::Inline

Class::Delegation

Test::Without::Module

Apache::Test

Math::Trig

GD

GD::SecurityImage

HTML::Template::Pluggable

Pod::Text

PerlBench::Stats

String::PerlIdentifier

Pod::Multi

MIME::Base32

Locale::Country

AIS::client

Tie::Restore

Date::Manip

String::Checker

Parse::RecDescent

Search::InvertedIndex

Lingua::Stem

Text::WikiFormat

Class::constr

Sys::Hostname::Long

IO::Util

File::MMagic

File::MMagic::XS

Image::Size

Devel::Cover

Image::Thumbnail

Image::ThousandWords

Bundle::Template::Magic

Time::Piece

Time::Piece::Adaptive

Time::Seconds

Data::MultiValuedHash

File::VirtualPath

HTML::EasyTags

Class::ParamParser

HTML::FormTemplate

Socket6

Convert::EBCDIC

Net::SMTP

CSS

HTML::WikiConverter

Bundle::Ensembl

Bundle::XML

Bundle::XML::Devel

Time::Local

Time::Zone

DB_File

File::Copy::Reliable

File::Copy::Link

FCGI

Mail::Sender

Data::Dump

Template::Plugin::Dump

Data::Dump::Streamer

Data::DumpXML

Data::Dumper::Again

Bundle::Sledge

Text::CSV_XS

Bundle::Kwiki

VCS::Lite

Module::Optional

Geo::Coordinates::UTM

File::Path::Expand

SpamMonkey

Test::Signature

Module::Signature

Scope::Guard

Class::C3

Class::C3::XS

MRO::Compat

Class::Inspector

Class::Accessor::Grouped

Module::Find

Carp::Clan

Class::Accessor::Chained

Data::Page

Test::Pod

Test::Pod::Coverage

DBIx::Class

HTML::SimpleParse

Template::Plugin::SSI

WWW::Authenticate

AppConfig::CGI

Log::Dispatch

Log::Dispatch::Config

Log::Channel

Text::Template

Pod::Escapes

HTML::Stream

Pod::Tree

URI::Find

Algorithm::Merge

Test::Prereq

Geography::NationalGrid

File::PathInfo

Time::Format

Time::Format_XS

Image::Magick::Thumbnail

Want

Gives

MIME::Lite

Mail::Address

Text::FormatTable

HTML::QuickTable

Crypt::HCE_SHA

Config::Auto

Config::IniFiles

DBD::Mock

HTML::Template::Compiled

HTML::FillInForm

Data::FormValidator

Bit::Vector

Date::Calc

UNIVERSAL::isa

UNIVERSAL::can

UNIVERSAL::exports

Devel::Sub::Which

Data::Table

B::Generate

Devel::Pointer

Devel::Pointer::PP

Class::Classless

Class::Object

Class::SelfMethods

Class::Prototyped

Class::Prototyped::Mixin

WWW::Mechanize

HTML::Template::Expr

MKDoc::Core

Getopt::Declare

URI::Find

MKDoc::Text::Structured

File::Touch

MKDoc::Forum

MKDoc::Control_List

MKDoc::XML

Petal

Config::General

Config::Context

Persistence::Object::Simple

Persistence::Object::Postgres

Persistence::Database::SQL

Text::Iconv

I18N::LangTags

Time::ParseDate

Geography::States

IO::CaptureOutput

Email::Valid

DateTime::Format::Strptime

List::MoreUtils

Email::Valid::Loose

FormValidator::Simple

Getargs::Long

Devel::StackTrace

Test::use::ok

Cache::Memcached

Data::Serializer

Crypt::Datum

Carp::Datum

LockFile::Simple

Log::Agent

Log::Agent::Logger

Log::Agent::Rotate

Class::DBI::Loader

Class::DBI::SQLite

Class::DBI::AbstractSearch

Apache::Session

Template::Alloy

Template::Alloy::XS

Bundle::Compress

Log::Dispatch::DBI

FindBin::Real

Net::Telnet

Class::AccessorMaker

Test::Distribution

Business::ISBN::Data

Business::ISBN

Data::Phrasebook

Carp::Assert::More

Test::LongString

NEXT

HTTP::Server::Simple

HTTP::Server::Simple::Static

Test::HTTP::Server::Simple

Test::WWW::Mechanize

Text::Tabs

Unix::ConfigFile

Unix::PasswdFile

HTTP::BrowserDetect

CGI::Prototype::Docs::Resources

Net::SSLeay

Business::OnlinePayment

Business::CreditCard

Business::CreditCard::Object

Date::Simple

URI::Find::Schemeless::Stricter

Test::Output

Date::Format

Exception::Class

Exception::Class::TryCatch

MIME::Tools

Mail::Header

Mail::Internet

HTML::GenerateUtil

Config::Simple

Syntax::Highlight::Perl::Improved

Pod::Xhtml

Test::Class

Class::ISA

SWISH::API::More

HTML::HiLiter

Number::Format

Math::String

Cache::Adaptive

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut

==> Bundle-CGI-Dependencies-0.02.tar.gz: Bundle-CGI-Dependencies-0.02/lib/Bundle/CGI/Dependencies.pm <==
package Bundle::CGI::Dependencies;

use strict;
use warnings;

our $VERSION = '0.02';



1;
__END__


=head1 NAME

Bundle::CGI::Dependencies - installs CGI prerequisites

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::CGI::Dependencies'

=head1 CONTENTS

CGI

File::Spec

Pod::Parser

Test::Harness

Test::Simple

Attribute::Handlers

Params::Validate

Getopt::Long

XSLoader

Data::Dumper

Module::Info

PadWalker

B::Utils

Text::Abbreviate

Text::Balanced 

Algorithm::Diff

Scalar::Util

IO

IO::Stringy

Getopt::Long

DBI

Getopt::Long::Descriptive

Data::Dump::Streamer

DBD::mysql

Regexp::Common

DBD::mysql::SimpleMySQL 

Devel::Leak

YAML

YAML::Syck

YAML::Tiny

Storable

ExtUtils::Constant

Time::HiRes

IPC::Run3

Test::Script

AutoLoader

HTML::Template

MIME::Base64

Digest

Digest::MD5

HTML::Tagset

HTML::Tree

HTML::Element::Library

HTML::Element::Convert

XML::TreeBuilder

HTML::ElementTable

HTML::TableExtract

XML::Parser

Test

version

ExtUtils::CBuilder

Config::IniFiles

Jcode

Encode

Bundle::Compress::Zlib

URI

HTTP::Daemon

Continuity

DBIx::ContextualFetch

UNIVERSAL::moniker

Clone

Ima::DBI

Class::Trigger

Class::Data::Inheritable

Class::DBI

Class::Contract

Pragmatic

Class::ISA

Class::Class

Class::Generate

Class::MethodMaker

CGI::Ajax

Digest::SHA1

Crypt::CBC

Crypt::DES

Crypt::DES_EDE3

Crypt::IDEA

Crypt::CAST5

Crypt::Rijndael

Crypt::Rijndael_PP

Crypt::Blowfish

DBD::SQLite

Bundle::SQL

Test::Exception

HTTP::Rollup

Template::Plugin::StringTree

Test::Assertions

Hash::Flatten

Log::Trace

Tie::ShareLite

IPC::Shareable

IPC::ShareLite

MIME::Types

Number::Compare

Text::Glob

Number::Compare

File::Find::Rule

File::Find::Rule::Type

File::Find::Rule::MMagic

File::Type

Cache::Cache

Crypt::UnixCrypt

Module::Load

Tree::DAG_Node

Sub::Uplevel

Array::Compare

UNIVERSAL::require

Test::Warn

Apache::Htgroup

Sub::Name

Class::MOP

Class::Accessor

HTML::Prototype

Module::Build

Template

IO::Zlib

File::Which

Digest::SHA::PurePerl

PAR::Dist

Archive::Zip

PAR 

Acme::Intraweb

Test::Inline

Class::Delegation

Test::Without::Module

Apache::Test

Math::Trig

GD

GD::SecurityImage

HTML::Template::Pluggable

Pod::Text

PerlBench::Stats

String::PerlIdentifier

Pod::Multi

MIME::Base32

Locale::Country

AIS::client

Tie::Restore

Date::Manip

String::Checker

Parse::RecDescent

Search::InvertedIndex

Lingua::Stem

Text::WikiFormat

Class::constr

Sys::Hostname::Long

IO::Util

File::MMagic

File::MMagic::XS

Image::Size

Devel::Cover

Image::Thumbnail

Image::ThousandWords

Bundle::Template::Magic

Time::Piece

Time::Piece::Adaptive

Time::Seconds

Data::MultiValuedHash

File::VirtualPath

HTML::EasyTags

Class::ParamParser

HTML::FormTemplate

Socket6

Convert::EBCDIC

Net::SMTP

CSS

HTML::WikiConverter

Bundle::XML

Bundle::XML::Devel

Time::Local

Time::Zone

DB_File

File::Copy::Reliable

File::Copy::Link

FCGI

Mail::Sender

Data::Dump

Template::Plugin::Dump

Data::Dump::Streamer

Data::DumpXML

Data::Dumper::Again

Bundle::Sledge

Text::CSV_XS

Bundle::Kwiki

VCS::Lite

Module::Optional

Geo::Coordinates::UTM

File::Path::Expand

SpamMonkey

Test::Signature

Module::Signature

Scope::Guard

Class::C3

Class::C3::XS

MRO::Compat

Class::Inspector

Class::Accessor::Grouped

Module::Find

Carp::Clan

Class::Accessor::Chained

Data::Page

Test::Pod

Test::Pod::Coverage

DBIx::Class

HTML::SimpleParse

Template::Plugin::SSI

WWW::Authenticate

AppConfig::CGI

Log::Dispatch

Log::Dispatch::Config

Log::Channel

Text::Template

Pod::Escapes

HTML::Stream

Pod::Tree

URI::Find

Algorithm::Merge

Test::Prereq

Geography::NationalGrid

File::PathInfo

Time::Format

Time::Format_XS

Image::Magick::Thumbnail

Want

Gives

MIME::Lite

Mail::Address

Text::FormatTable

HTML::QuickTable

Crypt::HCE_SHA

Config::Auto

Config::IniFiles

DBD::Mock

HTML::Template::Compiled

HTML::FillInForm

Data::FormValidator

Bit::Vector

Date::Calc

UNIVERSAL::isa

UNIVERSAL::can

UNIVERSAL::exports

Devel::Sub::Which

Data::Table

B::Generate

Devel::Pointer

Devel::Pointer::PP

Class::Classless

Class::Object

Class::SelfMethods

Class::Prototyped

Class::Prototyped::Mixin

WWW::Mechanize

HTML::Template::Expr

MKDoc::Core

Getopt::Declare

URI::Find

MKDoc::Text::Structured

File::Touch

MKDoc::Forum

MKDoc::Control_List

MKDoc::XML

Petal

Config::General

Config::Context

Persistence::Object::Simple

Persistence::Object::Postgres

Persistence::Database::SQL

Text::Iconv

I18N::LangTags

Time::ParseDate

Geography::States

IO::CaptureOutput

Email::Valid

DateTime::Format::Strptime

List::MoreUtils

Email::Valid::Loose

FormValidator::Simple

Getargs::Long

Devel::StackTrace

Test::use::ok

Cache::Memcached

Data::Serializer

Carp::Datum

LockFile::Simple

Log::Agent

Log::Agent::Logger

Log::Agent::Rotate

Class::DBI::Loader

Class::DBI::SQLite

Class::DBI::AbstractSearch

Apache::Session

Template::Alloy

Template::Alloy::XS

Bundle::Compress

Log::Dispatch::DBI

FindBin::Real

Net::Telnet

Class::AccessorMaker

Test::Distribution

Business::ISBN::Data

Business::ISBN

Data::Phrasebook

Carp::Assert::More

Test::LongString

NEXT

HTTP::Server::Simple

HTTP::Server::Simple::Static

Test::HTTP::Server::Simple

Test::WWW::Mechanize

Text::Tabs

Unix::ConfigFile

Unix::PasswdFile

HTTP::BrowserDetect

CGI::Prototype::Docs::Resources

Net::SSLeay

Business::OnlinePayment

Business::CreditCard

Business::CreditCard::Object

Date::Simple

URI::Find::Schemeless::Stricter

Test::Output

Date::Format

Exception::Class

Exception::Class::TryCatch

MIME::Tools

Mail::Header

Mail::Internet

HTML::GenerateUtil

Config::Simple

Syntax::Highlight::Perl::Improved

Pod::Xhtml

Test::Class

Class::ISA

SWISH::API::More

HTML::HiLiter

Number::Format

Math::String

Cache::Adaptive

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut
